"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.HasuraApi = void 0;
const axios_1 = __importDefault(require("axios"));
const debug_1 = __importDefault(require("debug"));
const debug = (0, debug_1.default)('hasura');
class HasuraApi {
    constructor(options) {
        this.defaultErrorHandler = (result) => console.log('error', result === null || result === void 0 ? void 0 : result.error, result === null || result === void 0 ? void 0 : result.data);
        this.options = Object.assign({ errorHandler: this.defaultErrorHandler }, options);
    }
    validateStatus() { return true; }
    ;
    getError(result) {
        const { status } = result;
        const error = status >= 200 && status < 300 ? null : result.statusText;
        return error;
    }
    sql(sql) {
        return this.query({
            type: 'run_sql',
            args: {
                sql,
            },
        }, {
            route: '/v1/query',
        });
    }
    explain(query) {
        return this.query({
            query: {
                query
            },
        }, {
            route: '/v1/graphql/explain',
        });
    }
    query(data, options = { route: '/v1/query' }) {
        return __awaiter(this, void 0, void 0, function* () {
            debug('query', data === null || data === void 0 ? void 0 : data.type);
            const result = yield (0, axios_1.default)({
                method: 'post',
                url: `http${this.options.ssl ? 's' : ''}://${this.options.path}${options === null || options === void 0 ? void 0 : options.route}`,
                headers: Object.assign({}, (this.options.secret ? { 'x-hasura-admin-secret': this.options.secret } : {})),
                data,
                validateStatus: this.validateStatus,
            });
            result.error = this.getError(result);
            if (result.error)
                this.options.errorHandler(result);
            return result;
        });
    }
    metadata(data, options = { route: '/v1/metadata' }) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.query(data, options);
        });
    }
}
exports.HasuraApi = HasuraApi;
//# sourceMappingURL=api.js.map